@@ -1,7 +1,7 @@
 use clap::{Args, Parser};
 use console::style;
 
-use crate::commands::{module_deploy_command, init_command, login_command, new_command, BaseCommand, build_command, publish_command, module_list_command, ModuleCommand, module_get_command};
+use crate::commands::{module_deploy_command, init_command, login_command, new_command, BaseCommand, build_command, publish_command, module_list_command, ModuleCommand, module_get_command, module_delete_command};
 
 mod commands;
 mod global_config;
@@ -37,7 +37,8 @@ fn main() {
         BaseCommand::Module(args) => match args.command {
             ModuleCommand::Deploy(args) => module_deploy_command(args),
             ModuleCommand::List(args) => module_list_command(args),
-            ModuleCommand::Get(args) => module_get_command(args)
+            ModuleCommand::Get(args) => module_get_command(args),
+            ModuleCommand::Delete(args) => module_delete_command(args)
         }
     };
 
